==> mauticGIT-Test-20251212_104643.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/6f/6ff3da942c0d777ff1a81703aa9b5a07.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/AssetBundle/Event/AssetLoadEvent.php */
class __TwigTemplate_8ee5b01f029775a943190179b7b61c3c extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\AssetBundle\\Event;

use Mautic\\AssetBundle\\Entity\\Download;
use Mautic\\CoreBundle\\Event\\CommonEvent;

class AssetLoadEvent extends CommonEvent
{
    public function __construct(
        Download \$download,
        protected bool \$unique
    ) {
        \$this->entity = \$download;
    }

    /**
     * Returns the Download entity.
     *
     * @return Download
     */
    public function getRecord()
    {
        return \$this->entity;
    }

    /**
     * @return \\Mautic\\AssetBundle\\Entity\\Asset
     */
    public function getAsset()
    {
        return \$this->entity->getAsset();
    }

    /**
     * Returns if this is the first download for the session.
     */
    public function isUnique(): bool
    {
        return \$this->unique;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/AssetBundle/Event/AssetLoadEvent.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/AssetBundle/Event/AssetLoadEvent.php", "/var/www/mautic-ktn/app/bundles/AssetBundle/Event/AssetLoadEvent.php");
    }
}

==> mauticGIT-Test-20260119_091040.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/6f/6ff3da942c0d777ff1a81703aa9b5a07.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/AssetBundle/Event/AssetLoadEvent.php */
class __TwigTemplate_8ee5b01f029775a943190179b7b61c3c extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\AssetBundle\\Event;

use Mautic\\AssetBundle\\Entity\\Download;
use Mautic\\CoreBundle\\Event\\CommonEvent;

class AssetLoadEvent extends CommonEvent
{
    public function __construct(
        Download \$download,
        protected bool \$unique
    ) {
        \$this->entity = \$download;
    }

    /**
     * Returns the Download entity.
     *
     * @return Download
     */
    public function getRecord()
    {
        return \$this->entity;
    }

    /**
     * @return \\Mautic\\AssetBundle\\Entity\\Asset
     */
    public function getAsset()
    {
        return \$this->entity->getAsset();
    }

    /**
     * Returns if this is the first download for the session.
     */
    public function isUnique(): bool
    {
        return \$this->unique;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/AssetBundle/Event/AssetLoadEvent.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/AssetBundle/Event/AssetLoadEvent.php", "/var/www/html/mauticGIT-Test/app/bundles/AssetBundle/Event/AssetLoadEvent.php");
    }
}
